@@ -22,10 +22,6 @@
  * Public functions
  */
 void
-builder_config_save (void)
-{
-  /* save UI stuff */
-  gnome_db_save_window_config("MainWindow", glb_mainwin);
-
-  gda_config_commit();
+builder_config_save (void) {
+	gda_config_commit();
 }
\ No newline at end of file
