@@ -138,7 +138,7 @@ gnome_db_config_get_shell_components (void)
   gint                i;
   
   CORBA_exception_init(&ev);
-  servlist = oaf_query("repo_ids.has('IDL:BonoboControl/gnome-db-shell-component:1.0')", NULL, &ev);
+  servlist = oaf_query("repo_ids.has('IDL:GNOME/DB/ShellComponent:1.0')", NULL, &ev);
   if (servlist)
     {
       for (i = 0; i < servlist->_length; i++)
