@@ -21,28 +21,26 @@
 #include "gnome-db-control-corba.h"
 #include "bonobo-ui-compat.h"
 
-struct _GnomeDbControlInstancePrivate
-{
-  GnomeDbControl*    control;
-  BonoboControl*     bonobo_control;
-  GtkWidget*         widget;
-  BonoboPropertyBag* properties;
-  BonoboUIComponent* ui_component;
-  BonoboUIHandler*   ui_handler;
-  GnomeUIInfo*       menubar;
-  GnomeUIInfo*       toolbar;
-  gpointer           user_data;
+struct _GnomeDbControlInstancePrivate {
+	GnomeDbControl*    control;
+	BonoboControl*     bonobo_control;
+	GtkWidget*         widget;
+	BonoboPropertyBag* properties;
+	BonoboUIComponent* ui_component;
+	BonoboUIHandler*   ui_handler;
+	GnomeUIInfo*       menubar;
+	GnomeUIInfo*       toolbar;
+	gpointer           user_data;
 };
 
-enum
-{
-  GET_PROPERTY,
-  SET_PROPERTY,
-  DO_PRINT,
-  DO_CUT_CLIPBOARD,
-  DO_COPY_CLIPBOARD,
-  DO_PASTE_CLIPBOARD,
-  LAST_SIGNAL
+enum {
+	GET_PROPERTY,
+	SET_PROPERTY,
+	DO_PRINT,
+	DO_CUT_CLIPBOARD,
+	DO_COPY_CLIPBOARD,
+	DO_PASTE_CLIPBOARD,
+	LAST_SIGNAL
 };
 
 static guint control_instance_signals[LAST_SIGNAL] = { 0, };
@@ -53,36 +51,31 @@ static guint control_instance_signals[LAST_SIGNAL] = { 0, };
 static void
 control_activated_cb (BonoboControl *bonobo_control,
                       gboolean activate,
-                      GnomeDbControlInstance *control_instance)
-{
-  if (activate) gnome_db_control_instance_activate(control_instance);
-  else gnome_db_control_instance_deactivate(control_instance);
+                      GnomeDbControlInstance *control_instance) {
+	if (activate) gnome_db_control_instance_activate(control_instance);
+	else gnome_db_control_instance_deactivate(control_instance);
 }
 
 static void
-control_destroyed_cb (GnomeDbControlInstance *control_instance, gpointer data)
-{
-  CORBA_Environment ev;
-
-  g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));  
-  g_free((gpointer) control_instance->priv);
+control_destroyed_cb (GnomeDbControlInstance *control_instance, gpointer data) {
+	CORBA_Environment ev;
+	
+	g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));
+	g_free((gpointer) control_instance->priv);
 }
 
 static void
-get_prop_cb (BonoboPropertyBag *bag, BonoboArg *arg, guint arg_id, gpointer user_data)
-{
+get_prop_cb (BonoboPropertyBag *bag, BonoboArg *arg, guint arg_id, gpointer user_data) {
 }
 
 static void
-set_prop_cb (BonoboPropertyBag *bag, const BonoboArg *arg, guint arg_id, gpointer user_data)
-{
+set_prop_cb (BonoboPropertyBag *bag, const BonoboArg *arg, guint arg_id, gpointer user_data) {
 }
 
 static void
-widget_destroyed_cb (GtkWidget *w, GnomeDbControlInstance *control_instance)
-{
-  g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));
-  gtk_object_unref(GTK_OBJECT(control_instance));
+widget_destroyed_cb (GtkWidget *w, GnomeDbControlInstance *control_instance) {
+	g_return_if_fail(GNOME_DB_IS_CONTROL_INSTANCE(control_instance));
+	gtk_object_unref(GTK_OBJECT(control_instance));
 }
 
 /*
